from Products.CMFCore.utils import getToolByName 

from OFS.SimpleItem import SimpleItem
from persistent import Persistent 

from zope.interface import implements, Interface
from zope.component import adapts
from zope.formlib import form
from zope import schema

from plone.contentrules.rule.interfaces import IExecutable, IRuleElementData
from plone.app.contentrules.browser.formhelper import AddForm, EditForm, NullAddForm 

from Products.statusmessages.interfaces import IStatusMessage
from Products.CMFPlone import PloneMessageFactory as _
from Products.CMFPlone import PloneMessageFactory



class IResetFeaturesAction(Interface):
    """Interface for the featured tip action.
        This is also used to create add and edit forms, below.
    """
    pass
         
class ResetFeaturesAction(SimpleItem):
    """The actual persistent implementation of the notify action element.
    """
    implements(IResetFeaturesAction, IRuleElementData)
    
    message = ''
    message_type = ''
    
    element = 'plone.actions.ResetFeatures'
    
    @property
    def summary(self):
        return _(u"Resets featured state of other Documents ${message}", mapping=dict(message=self.message))

class ResetFeaturesActionExecutor(object):
    """The executor for this action.
    
    This is registered as an adapter in configure.zcml
    """
    implements(IExecutable)
    adapts(Interface, IResetFeaturesAction, Interface)
         
    def __init__(self, context, element, event):
        self.context = context
        self.element = element
        self.event = event

    def __call__(self):
        obj = self.event.object
        parent = obj.getParentNode()
        obj_path = '/'.join(parent.getPhysicalPath())

        wftool = getToolByName(self.context, 'portal_workflow')
        
        catalog = getToolByName(self.context, 'portal_catalog') 
        for result in catalog(portal_type = ('Document',),
                              path = obj_path,
                              featured_state=('featured',)): 
            result_obj = result.getObject()

            # do something with the review_state 
            # To change the workflow state of an object, you can use: 

            wftool.doActionFor(result_obj, action='unfeature')
            result_obj.reindexObject()
            
        return True 
        
class ResetFeaturesAddForm(NullAddForm):
    """An add form for notify rule actions.
    """
    form_fields = form.FormFields(IResetFeaturesAction)
    label = _(u"Add ResetFeatures Action")
    description = _(u"A notify action can show a message to the user.")
    form_name = _(u"Configure element")
    
    def create(self):
        return ResetFeaturesAction()

